'use strict';

exports.__esModule = true;

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

require('./stepper.css');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Creates a stepper.
 * @param {array} steps - Names of different steps.
 * @param {number} activeStep - Index of the active step.
 * @param {string} className - Classname of the component.
 * @returns {ReactElement} - Stepper generated
 */
var Stepper = function Stepper(_ref) {
  var steps = _ref.steps,
      activeStep = _ref.activeStep,
      className = _ref.className;

  var stepsLines = steps.reduce(function (r, a) {
    return r.concat(a, false);
  }, []);
  stepsLines.pop();
  return _react2.default.createElement(
    'div',
    { className: 'Stepper ' + className },
    stepsLines.map(function (step, i) {
      return i % 2 ? _react2.default.createElement('div', {
        key: i,
        className: 'Stepper-line ' + (++activeStep >= i ? 'Stepper-activeStep' : '')
      }) : _react2.default.createElement(
        'div',
        {
          key: i,
          className: 'Stepper-step ' + (activeStep >= i ? 'Stepper-activeStep' : '')
        },
        step
      );
    })
  );
};

Stepper.propTypes = process.env.NODE_ENV !== "production" ? {
  // State
  steps: _propTypes2.default.arrayOf(_propTypes2.default.string).isRequired,
  activeStep: _propTypes2.default.number.isRequired,

  // Modifiers
  className: _propTypes2.default.string
} : {};

Stepper.defaultProps = {
  // Modifiers
  className: ''
};

exports.default = Stepper;
module.exports = exports['default'];